@@ -41,10 +41,10 @@ class RoutesMiddleware(object):
             req = WSGIRequest(environ)
             if '_method' in environ.get('QUERY_STRING', '') and '_method' in req.GET:
                 old_method = environ['REQUEST_METHOD']
-                environ['REQUEST_METHOD'] = req.GET['_method']
+                environ['REQUEST_METHOD'] = req.GET['_method'].upper()
             elif environ['REQUEST_METHOD'] == 'POST' and '_method' in req.POST:
                 old_method = environ['REQUEST_METHOD']
-                environ['REQUEST_METHOD'] = req.POST['_method']
+                environ['REQUEST_METHOD'] = req.POST['_method'].upper()
         
         config.environ = environ
         match = config.mapper_dict
